$set 3  #arp

$ #_hostname Original Message:(arp: need host name\n)
# arp: nécessite un nom d'hôte\n

$ #_no_arp Original Message:(No ARP entry for %s\n)
# Pas d'entrée ARP pour %s\n

$ #_need_hw Original Message:(arp: need hardware address\n)
# arp: nécessite une adresse matérielle\n

$ #_invalidhw Original Message:(arp: invalid hardware address\n)
# arp: adresse matérielle invalide\n

$ #_cant_open Original Message:(arp: cannot open etherfile %s !\n)
# arp: ne peut ouvrir le fichier %s !\n

$ #_formaterr Original Message:(arp: format error on line %u of etherfile %s !\n)
# arp: erreur de format à la ligne %u du fichier %s !\n

$ #_cant_set Original Message:(arp: cannot set entry on line %u of etherfile %s !\n)
# arp: ne peut pas définir l'entrée à la ligne %u du fichier %s !\n

$ #_address1 Original Message:(Address\t\t\tHW type\t\tHW address\t\tFlags\n)
# Adresse\t\t\tType de Mat.\tAdresse Mat.\t\tOpts\n

$ #_address2 Original Message:(Address\t\t\tHW type\t\tHW address\t\tFlags\tMask\n)
# Adresse\t\t\tType de Mat.\tAdresse Mat.\t\tOpts\tMasque\n

$ #_usage1 Original Message:(Usage: arp [-vn] [-p proto] [-t type] -a [hostname]\n)
# Syntaxe: arp [-vn] [-p proto] [-t type] -a [nom_d_hôte]\n

$ #_usage2 Original Message:(       arp [-v] [-p proto] -d hostname ...\n)
#          arp [-v] [-p proto] -d nom_d_hôte ...\n

$ #_usage3 Original Message:(       arp [-v] [-p proto] [-t type] -s hostname hw_addr [netmask aa.bb.cc.dd] [temp|pub|trail]\n)
#          arp [-v] [-p proto] [-t type] -s nom_d_hôte adr_ethernet [netmask aa.bb.cc.dd] [temp|pub|trail]\n

$ #_usage4 Original Message:(       arp [-vn] -f filename\n)
#          arp [-vn] -f nom_de_fichier\n

$ #_usage5 Original Message:(       Note: netmask may only be used with the pub option\n)
#          Note: netmask ne peut etre utilisé qu'avec l'option pub\n

$ #_hw_not_supp Original Message:(%s: hardware type not supported!\n)
# %s: type de matériel pas supporté!\n

$ #_fam_not_supp Original Message:(%s: address family not supported!\n)
# %s: famille d'adresse pas supportée !\n

$ #_unkn_addr Original Message:(arp: %s: unknown address family.\n)
# arp: %s: famille d'adresse inconnue.\n

$ #_unkn_hw Original Message:(arp: %s: unknown hardware type.\n)
# arp: %s: type de matériel inconnu.\n

