$set 5  #hostname

$ #_root Original Message:(%s: you must be root to change the host name\n)
# %s: vous devez etre super-utilisateur pour changer le nom d'hôte\n

$ #_toolong Original Message:(%s: name too long\n)
# %s: nom trop long\n

$ #_cant_find Original Message:(%s: can't find a FQDN for the host name `%s'\n)
# %s: ne trouve pas de FQDN pour le nom d'hôte `%s'\n

$ #_nodns1 Original Message:(%s: You can't change the DNS domain name with this command\n)
# %s: Vous ne pouvez pas changer le nom de domainde DNS avec cette commande\n

$ #_nodns2 Original Message:(\nUnless you are using bind or NIS for host lookups you can change the DNS\n)
# \nSauf si vous utilisez `bind' ou NIS pour la recherche des hôtes, vous pouvez changer le nom\n

$ #_nodns3 Original Message:(domain name (which is part of the FQDN) in the /etc/hosts file.\n)
# de domaine DNS (qui fait partie de FQDN) dans le fichier /etc/hosts.\n

$ #_cant_open Original Message:(%s: can't open `%s'\n)
# %s: ne peut ouvrir `%s'\n

$ #_try Original Message:(Try `%s --help' for more information.\n)
# Essayez `%s --help' pour plus d'informations.\n

$ #_usage1 Original Message:(Usage: %s [OPTION]... [hostname]\n\n)
# Syntaxe: %s [OPTION]... [nom d'hôte]\n\n

$ #_usage2 Original Message:(  -d, --domain                 display the DNS domain name\n)
#   -d, --domain                 affiche le nom de domaine DNS\n

$ #_usage3 Original Message:(  -F, --file filename          read the host name from file\n)
#   -F, --file filename          lit le nom d'hôte à partir du fichier\n

$ #_usage4 Original Message:(  -f, --fqdn, --long           display the long host name (FQDN)\n)
#   -f, --fqdn, --long           affiche le nom complet de l'hôte (FQDN)\n

$ #_usage5 Original Message:(  -s, --short                  display the short host name\n)
#   -s, --short                  affiche le nom réduit de l'hôte\n

$ #_usage6 Original Message:()  -h, --help                   display this help and exit\n)
#   -h, --help                   affiche cette aide et termine\n

$ #_usage7 Original Message:(  -v, --version                output version information and exit\n\n)
#   -v, --version                donne les informations sur la version et termine\n\n

$ #_usage8 Original Message:(  When the program is called without any arguments, it displays the\n)
#   Quand le programme est appelé sans argument, il affiche le nom d'hôte\n

$ #_usage9 Original Message:(  current host name as set by the hostname command. If an argument\n)
#   courant tel que positionné par la commande hostname. Si un argument\n

$ #_usage10 Original Message:(  is given, the program will set the value of the host name to the\n)
#   est donné, le programme positionnera la valeur du nom d'hôte à la\n

$ #_usage11 Original Message:(  value specified.\n)
#   valeur spécifiée.\n

$ #_usage12 Original Message:(  Unless you are using bind or NIS for host lookups you can change the\n)
#   Sauf si vous utilisez `bind' ou NIS pour la recherche des hôtes, vous pouvez\n

$ #_usage13 Original Message:(  FQDN (Fully Qualified Domain Name) and the DNS domain name (which is\n)
#   changer le FQDN (Nom de Domaine Désigné Complètement) et le nom de domaine\n

$ #_usage14 Original Message:(  part of the FQDN) in the /etc/hosts file.\n)
#    DNS (qui fait partie du FQDN) dans le fichier /etc/hosts.\n
