$set 8  #slattach

$ #_user_unkn Original Message:(slattach: tty_lock: UUCP user %s unknown!\n)
# slattach: tty_lock: UUCP utilisateur %s inconnu !\n

$ #_drop Original Message:(slattach: tty_hangup(DROP): %s\n)
# slattach: tty_hangup(TERMINAISON): %s\n

$ #_raise Original Message:(slattach: tty_hangup(RAISE): %s\n)
# slattach: tty_hangup(OBTENTION): %s\n

$ #_cant_state Original Message:(slattach: tty_open: cannot get current state!\n)
# slattach: tty_open: ne peut pas obtenir l'état courant !\n

$ #_cant_disc Original Message:(slattach: tty_open: cannot get current line disc!\n)
# slattach: tty_open: ne peut pas obtenir la discipline de ligne courante !\n

$ #_cant_raw Original Message:(slattach: tty_open: cannot set RAW mode!\n)
# slattach: tty_open: ne peut pas positionner le mode RAW !\n

$ #_cant_bps Original Message:(slattach: tty_open: cannot set %s bps!\n)
# slattach: tty_open: ne peut pas positionner %s bps!\n

$ #_cant_8n1 Original Message:(slattach: tty_open: cannot set 8N1 mode!\n)
# slattach: tty_open: ne peut pas définir le mode 8N1 !\n

$ #_usage1 Original Message:(Usage: slattach [-ehlLmnqv] [-c cmd] [-s speed] [-p protocol] tty | -\n)
# Usage: slattach [-ehlLmnqv] [-c cmd] [-s vitesse] [-p protocole] tty | -\n

$ #_unsupp Original Message:(slattach: unsupported protocol %s\n)
# slattach: protocole %s pas supporté\n

$ #_started Original Message:(%s started)
# %s démarré

$ #_on Original Message:( on %s)
#  sur %s

$ #_iface Original Message:( interface %s\n)
#  interface %s\n
