$set 1  #ifconfig

$ #_over Original Message:(overruns)
# overruns

$ #_compress Original Message:(compressed)
# compressed

$ #_link Original Message:(%-8.8s  Link encap:%s  )
# %-8.8s  Link encap:%s  

$ #_hw Original Message:(HWaddr %s)
# HWaddr %s

$ #_adr Original Message:(\n          %s addr:%s)
# \n          %s addr:%s

$ #_pap Original Message:(  P-t-P:%s  )
#   P-t-P:%s  

$ #_bcast Original Message:(  Bcast:%s  )
#   Bcast:%s  

$ #_mask Original Message:(Mask:%s\n)
# Mask:%s\n

$ #_etherII Original Message:(          IPX/Ethernet II addr:%s\n)
#           IPX/Ethernet II addr:%s\n

$ #_SNAP Original Message:(          IPX/Ethernet SNAP addr:%s\n)
#           IPX/Ethernet SNAP addr:%s\n

$ #_8022 Original Message:(          IPX/Ethernet 802.2 addr:%s\n)
#           IPX/Ethernet 802.2 addr:%s\n

$ #_8023 Original Message:(          IPX/Ethernet 802.3 addr:%s\n)
#           IPX/Ethernet 802.3 addr:%s\n

$ #_talk Original Message:(          EtherTalk Phase 2 addr:%s\n)
#           EtherTalk Phase 2 addr:%s\n

$ #_noflags Original Message:([NO FLAGS] )
# [NO FLAGS] 

$ #_mtu Original Message:( MTU:%d  Metric:%d\n)
#  MTU:%d  Metric:%d\n

$ #_rx Original Message:(RX packets:%u errors:%u dropped:%u %s:%u\n)
# RX packets:%u errors:%u dropped:%u %s:%u\n

$ #_tx Original Message:(TX packets:%u errors:%u dropped:%u %s:%u\n)
# TX packets:%u errors:%u dropped:%u %s:%u\n

$ #_interrupt Original Message:(Interrupt:%d )
# Interrupt:%d 

$ #_base Original Message:(Base address:0x%x )
# Base address:0x%x 

$ #_mem Original Message:(Memory:%lx-%lx )
# Memory:%lx-%lx 

$ #_dma Original Message:(DMA chan:%x )
# DMA chan:%x 

$ #_unkn Original Message:(%s: unknown interface.\n)
# %s: unknown interface.\n

$ #_usage1 Original Message:(Usage: ifconfig [-a] [-i] [-v] interface\n)
# Usage: ifconfig [-a] [-i] [-v] interface\n

$ #_usage2 Original Message:(                [inet address]\n)
#                 [inet address]\n

$ #_usage3 Original Message:(                [hw] [ax25 address]\n)
#                 [hw] [ax25 address]\n
