$set 20  #netrom

$ #_none Original Message:([NONE SET])
# [NONE SET]

$ #_debug1 Original Message:(Invalid callsign)
# Invalid callsign

$ #_debug2 Original Message:(Callsign too long)
# Callsign too long

$ #_hw Original Message:(AMPR NetROM)
# AMPR NetROM

$ #_netrom Original Message:(AMPR NetROM)
# AMPR NetROM

