$set 5  #hostname

$ #_root Original Message:(%s: you must be root to change the host name\n)
# %s: you must be root to change the host name\n

$ #_toolong Original Message:(%s: name too long\n)
# %s: name too long\n

$ #_cant_find Original Message:(%s: can't find a FQDN for the host name `%s'\n)
# %s: can't find a FQDN for the host name `%s'\n

$ #_nodns1 Original Message:(%s: You can't change the DNS domain name with this command\n)
# %s: You can't change the DNS domain name with this command\n

$ #_nodns2 Original Message:(\nUnless you are using bind or NIS for host lookups you can change the DNS\n)
# \nUnless you are using bind or NIS for host lookups you can change the DNS\n

$ #_nodns3 Original Message:(domain name (which is part of the FQDN) in the /etc/hosts file.\n)
# which is part of the FQDN) in the /etc/hosts file.\n

$ #_cant_open Original Message:(%s: can't open `%s'\n)
# %s: can't open `%s'\n

$ #_try Original Message:(Try `%s --help' for more information.\n)
# Try `%s --help' for more information.\n

$ #_usage1 Original Message:(Usage: %s [OPTION]... [hostname]\n\n)
# Usage: %s [OPTION]... [hostname]\n\n

$ #_usage2 Original Message:(  -d, --domain                 display the DNS domain name\n)
#   -d, --domain                 display the DNS domain name\n

$ #_usage3 Original Message:(  -F, --file filename          read the host name from file\n)
#   -F, --file filename          read the host name from file\n

$ #_usage4 Original Message:(  -f, --fqdn, --long           display the long host name (FQDN)\n)
#   -f, --fqdn, --long           display the long host name (FQDN)\n

$ #_usage5 Original Message:(  -s, --short                  display the short host name\n)
#   -s, --short                  display the short host name\n

$ #_usage6 Original Message:(  -h, --help                   display this help and exit\n)
#   -h, --help                   display this help and exit\n

$ #_usage7 Original Message:(  -v, --version                output version information and exit\n\n)
#   -v, --version                output version information and exit\n\n

$ #_usage8 Original Message:(  When the program is called without any arguments, it displays the\n)
#   When the program is called without any arguments, it displays the\n

$ #_usage9 Original Message:(  current host name as set by the hostname command. If an argument\n)
#   current host name as set by the hostname command. If an argument\n

$ #_usage10 Original Message:(  is given, the program will set the value of the host name to the\n)
#   is given, the program will set the value of the host name to the\n

$ #_usage11 Original Message:(  value specified.\n)
#   value specified.\n

$ #_usage12 Original Message:(  Unless you are using bind or NIS for host lookups you can change the\n)
#   Unless you are using bind or NIS for host lookups you can change the\n

$ #_usage13 Original Message:(  FQDN (Fully Qualified Domain Name) and the DNS domain name (which is\n)
#   FQDN (Fully Qualified Domain Name) and the DNS domain name (which is\n

$ #_usage14 Original Message:(  part of the FQDN) in the /etc/hosts file.\n)
#   part of the FQDN) in the /etc/hosts file.\n
