$set 10  #arcnet

$ #_none Original Message:([NONE SET])
# [NONE SET]

$ #_debug1 Original Message:(in_arcnet(%s): invalid arcnet address!\n)
# in_arcnet(%s): invalid arcnet address!\n

$ #_debug2 Original Message:(in_arcnet(%s): invalid arcnet address!\n)
# in_arcnet(%s): invalid arcnet address!\n

$ #_debug3 Original Message:(in_arcnet(%s): trailing : ignored!\n)
# in_arcnet(%s): trailing : ignored!\n

$ #_debug4 Original Message:(in_arcnet(%s): trailing junk!\n)
# in_arcnet(%s): trailing junk!\n

$ #_arcnet Original Message:(1.5Mbps ARCnet)
# 1.5Mbps ARCnet

