$set 18  #slip

$ #_slip Original Message:(Serial Line IP)
# Ligne Série IP

$ #_cslip Original Message:(VJ Serial Line IP)
# Ligne Série `VJ' IP

$ #_slip6 Original Message:(6-bit Serial Line IP)
# Ligne Série `6-bits' IP

$ #_cslip6 Original Message:(VJ 6-bit Serial Line IP)
# Ligne Série `VJ 6-bits' IP

$ #_adaptive Original Message:(Adaptive Serial Line IP)
# Ligne Série `Adaptative' IP

