$set 4  #netstat

$ #_table Original Message:(Kernel routing table\n)
# Kernel routing table\n

$ #_header Original Message:(Destination     Gateway         Genmask         Flags Metric Ref Use    Iface\n)
# Destination     Gateway         Genmask         Flags Metric Ref Use    Iface\n

$ #_route Original Message:(route: unsupported address family %d !\n)
# route: unsupported address family %d !\n

$ #_args Original Message:(%s -> %d args)
# %s -> %d args

$ #_netstat Original Message:(netstat: unsupported address family %d !\n)
# netstat: unsupported address family %d !\n

$ #_UNKN Original Message:(UNKNOWN)
# UNKNOWN

$ #_off Original Message:(off (0.00/%ld))
# off (0.00/%ld)

$ #_on Original Message:(on (%2.2f/%ld))
# on (%2.2f/%ld)

$ #_unkn Original Message:(unkn-%d (%2.2f/%ld))
# unkn-%d (%2.2f/%ld)

$ #_off2 Original Message:(off (0.00/%ld) %c)
# off (0.00/%ld) %c

$ #_on2 Original Message:(on (%2.2f/%ld) %c)
# on (%2.2f/%ld) %c

$ #_unkn2 Original Message:(unkn-%d (%2.2f/%ld) %c)
# unkn-%d (%2.2f/%ld) %c

$ #_off3 Original Message:(off (0.00/%ld) %c)
# off (0.00/%ld) %c

$ #_on3 Original Message:(on (%2.2f/%ld) %c)
# on (%2.2f/%ld) %c

$ #_unkn3 Original Message:(unkn-%d (%2.2f/%ld) %c)
# unkn-%d (%2.2f/%ld) %c

$ #_unix Original Message:(Active UNIX domain sockets\n)
# Active UNIX domain sockets\n

$ #_header_unix Original Message:(Proto RefCnt Flags      Type            State           Path\n)
# Proto RefCnt Flags      Type            State           Path\n

$ #_noax25 Original Message:(AX.25 not configured in this system.\n)
# AX.25 not configured in this system.\n

$ #_ax25 Original Message:(Activate AX.25 sockets\n)
# Activate AX.25 sockets\n

$ #_header_ax25 Original Message:(Destination   Source      Type      State     Vr/Vs   Protocol\n)
# Destination   Source      Type      State     Vr/Vs   Protocol\n

$ #_noipx Original Message:(IPX not configured in this system.\n)
# IPX not configured in this system.\n

$ #_noflags Original Message:([NO FLAGS])
# [NO FLAGS]

$ #_interface Original Message:(Kernel Interface table\n)
# Kernel Interface table\n

$ #_header_iface Original Message:(Iface   MTU Met  RX-OK RX-ERR RX-DRP RX-OVR  TX-OK TX-ERR TX-DRP TX-OVR Flags\n)
# Iface   MTU Met  RX-OK RX-ERR RX-DRP RX-OVR  TX-OK TX-ERR TX-DRP TX-OVR Flags\n

$ #_unkn_iface Original Message:(%s: unknown interface.\n)
# %s: unknown interface.\n

$ #_usage1 Original Message:(Usage:\tnetstat [options]\n)
# Usage:\tnetstat [options]\n

$ #_usage2 Original Message:(\t-a also listening sockets\n)
# \t-a also listening sockets\n

$ #_usage3 Original Message:(\t-c continous listing\n)
# \t-c continous listing\n

$ #_usage4 Original Message:(\t-i interface statistics\n)
# \t-i interface statistics\n

$ #_usage5 Original Message:(\t-n show network numbers instead of names\n)
# \t-n show network numbers instead of names\n

$ #_usage6 Original Message:(\t-o show timer states\n)
# \t-o show timer states\n

$ #_usage7 Original Message:(\t-r show kernel routing table\n)
# \t-r show kernel routing table\n

$ #_usage8 Original Message:(\t-t show active tcp connections\n)
# \t-t show active tcp connections\n

$ #_usage9 Original Message:(\t-u show active udp connections\n)
# \t-u show active udp connections\n

$ #_usage10 Original Message:(\t-v show version information\n)
# \t-v show version information\n

$ #_usage11 Original Message:(\t-w show active raw connections\n)
# \t-w show active raw connections\n

$ #_usage12 Original Message:(\t-x show active unix sockets\n)
# \t-x show active unix sockets\n

$ #_internet Original Message:(Active Internet connections)
# Active Internet connections

$ #_servers Original Message:( (including servers))
#  (including servers)

$ #_header_internet Original Message:(\nProto Recv-Q Send-Q Local Address          Foreign Address        (State)       User\n)
# \nProto Recv-Q Send-Q Local Address          Foreign Address        (State)       User\n

$ #_header_ipx Original Message:(Active IPX sockets\nProto Recv-Q Send-Q Local Address          Foreign Address        (State)       User\n)
# Active IPX sockets\nProto Recv-Q Send-Q Local Address          Foreign Address        (State)       User\n

$ #_type_no_route Original Message:(No routing for this socket family.\n)
# No routing for this socket family.\n

$ #_route_no_support Original Message:(No yet supported.\n)
# Not yet supported.\n
