$set 1  #ifconfig

$ #_over Original Message:(overruns)
# expirés

$ #_compress Original Message:(compressed)
# compressés

$ #_link Original Message:(%-8.8s  Link encap:%s  )
# %-8.8s  Type de lien:%s  

$ #_hw Original Message:(HWaddr %s)
# adresse ethernet %s

$ #_adr Original Message:(\n          %s addr:%s)
# \n          adr %s:%s

$ #_pap Original Message:(  P-t-P:%s  )
#   P-à-P:%s  

$ #_bcast Original Message:(  Bcast:%s  )
#   Diffusion:%s  

$ #_mask Original Message:(Mask:%s\n)
# Masque:%s\n

$ #_etherII Original Message:(          IPX/Ethernet II addr:%s\n)
#           IPX/Ethernet II adr:%s\n

$ #_SNAP Original Message:(          IPX/Ethernet SNAP addr:%s\n)
#           IPX/Ethernet SNAP adr:%s\n

$ #_8022 Original Message:(          IPX/Ethernet 802.2 addr:%s\n)
#           IPX/Ethernet 802.2 adr:%s\n

$ #_8023 Original Message:(          IPX/Ethernet 802.3 addr:%s\n)
#           IPX/Ethernet 802.3 adr:%s\n

$ #_talk Original Message:(          EtherTalk Phase 2 addr:%s\n)
#           EtherTalk Phase 2 adr:%s\n

$ #_noflags Original Message:([NO FLAGS] )
# [PAS D'OPTIONS] 

$ #_mtu Original Message:( MTU:%d  Metric:%d\n)
#  MTU:%d  Métrique:%d\n

$ #_rx Original Message:(RX packets:%u errors:%u dropped:%u %s:%u\n)
# RX paquets:%u erreurs:%u perdus:%u %s:%u\n

$ #_tx Original Message:(TX packets:%u errors:%u dropped:%u %s:%u\n)
# TX paquets:%u erreurs:%u perdus:%u %s:%u\n

$ #_interrupt Original Message:(Interrupt:%d )
# Interruption:%d 

$ #_base Original Message:(Base address:0x%x )
# Adresse de base:0x%x 

$ #_mem Original Message:(Memory:%lx-%lx )
# Mémoire:%lx-%lx 

$ #_dma Original Message:(DMA chan:%x )
# Canal DMA:%x 

$ #_unkn Original Message:(%s: unknown interface.\n)
# %s: interface inconnue.\n

$ #_usage1 Original Message:(Usage: ifconfig [-a] [-i] [-v] interface\n)
# Syntaxe: ifconfig [-a] [-i] [-v] interface\n

$ #_usage2 Original Message:(                [inet address]\n)
#                 [[inet] adresse inet]\n

$ #_usage3 Original Message:(                [hw] [ax25 address]\n)
#                 [hw] [adresse ax25]\n
